@@ -77,27 +77,25 @@ def box_extraction(page):
     return contours, hierarchy, img_final_bin
 
 
-def get_investment_pages(pdf_bytes):
+def get_investment_pages(
+    pages: List[Image.Image],
+):
+    """Guess which pages are our pages
+
+    :param pages: List of pages as images
+    :return: Tuple of pages
     """
 
-    :param pdf_bytes:
-    :return:
-    """
-
-    with tempfile.NamedTemporaryFile() as tmp:
-        tmp.write(pdf_bytes)
-
-        pg_count = PdfFileReader(tmp.name).numPages
-        pages = convert_from_path(tmp.name)
-        if pg_count == "6":
-            return pages[:3], pages[3:-2], pages[-2]
-        cv_image = np.array(pages[3])
-        avg_color_per_row = np.average(cv_image, axis=0)
-        avg_color = np.average(avg_color_per_row, axis=0)
-        if avg_color[0] > 245:
-            return pages[:4], pages[4:-2], pages[-2]
-        else:
-            return pages[:3], pages[3:-2], pages[-2]
+    pg_count = len(pages)
+    if pg_count == "6":
+        return pages[:3], pages[3:-2], pages[-2]
+    cv_image = np.array(pages[3])
+    avg_color_per_row = np.average(cv_image, axis=0)
+    avg_color = np.average(avg_color_per_row, axis=0)
+    if avg_color[0] > 245:
+        return pages[:4], pages[4:-2], pages[-2]
+    else:
+        return pages[:3], pages[3:-2], pages[-2]
 
 
 def get_text_fields(non_investment_pages):
@@ -343,7 +341,6 @@ def extract_section_VII(
     :param investment_pages:
     :return:
     """
-    last_data = None
     threads = []
     k = "Investments and Trusts"
     columns = results["sections"]["Investments and Trusts"]["fields"]
@@ -369,14 +366,9 @@ def extract_section_VII(
         # Occasionally the judicial watch documents have multiple documents
         # appended to them.  In this case, we stop processing after we
         # no longer detect multiple rows to process
-        if last_data is None:
-            last_data = len(data)
-        else:
-            if last_data < 5:
-                break
+        logging.info(f"Processing page {pg_count}")
     for thread in threads:
         thread.join()
-
     return results
 
 
